window.Gleam.initSearch([{"doc":"glimra","title":"glimra","content":"# glimra\n\n[![Package Version](https://img.shields.io/hexpm/v/glimra)](https://hex.pm/packages/glimra)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glimra/)\n![Erlang-compatible](https://img.shields.io/badge/target-erlang-b83998)\n\nZero runtime syntax highlighter for [`lustre/ssg`](https://github.com/lustre-labs/ssg).\n\n&gt; In Swedish, `glimra` describes the brilliant gleam or lustre that comes from a polished, reflective surface, capturing the essence of light shining off something smooth and glossy.\n\n## Platform support\n\n`glimra` uses [NIFs](https://www.erlang.org/doc/system/nif) to extract syntax highlighting events provided by the [`tree-sitter`](https://crates.io/crates/tree-sitter) and [`tree-sitter-highlight`](https://crates.io/crates/tree-sitter-highlight) crates. This allows `glimra` to provide syntax highlighting for a wide range of languages with minimal effort.\n\nUnfortunately, this also means that `glimra` only works with the Erlang target. You can use the provided precompiled binaries for the supported platforms or compile the NIFs yourself with the Rust toolchain.\n\nCurrently, the following operating systems and architectures are supported:\n\n| OS      | Architecture(s) |\n| ------- | --------------- |\n| Linux   | x86_64          |\n| macOS   | aarch64, x86_64 |\n| Windows | x86_64          |\n\n## Installation\n\n```sh\ngleam add glimra\n```\n\n## Usage\n\n`glimra` can be used to highlight source code snippets in a variety of languages. While the primary use case is to provide syntax highlighting for code snippets in the `lustre/ssg` static site generator, it can also be used in a more standalone fashion:\n\n```gleam\nimport glimra\nimport glimra/theme\n\npub fn main() {\n  let syntax_highlighter =\n    glimra.new_syntax_highlighter() |&gt; glimra.set_theme(theme.default_theme())\n\n  let source = &quot;let greeting = \\&quot;Hello, Joe!\\&quot;&quot;\n  let language = &quot;gleam&quot;\n\n  let highlighted_snippet =\n    syntax_highlighter\n    |&gt; glimra.syntax_highlight(source:, language:)\n\n  let css = syntax_highlighter |&gt; glimra.to_css()\n}\n```\n\n### Usage with `lustre/ssg`\n\n`glimra` provides a set of utilities to make it easier to work with `glimra` and `lustre/ssg`.\n\nGiven a typical `lustre/ssg` `build.gleam` file with the following `main()` function, you can generate and add the static stylesheet using the `add_static_stylesheet` builder:\n\n```gleam\nimport glimra\nimport glimra/theme\n\npub fn main() {\n  let syntax_highlighter =\n    glimra.new_syntax_highlighter()\n    |&gt; glimra.set_theme(theme.default_theme())\n\n  let build = ssg.new(&quot;./priv&quot;)\n    |&gt; ssg.add_static_route(&quot;/&quot;, index.view())\n    |&gt; ssg.add_static_route(&quot;/blog&quot;, blog.view(posts.all()))\n    // the `add_static_stylesheet` builder works with your existing `lustre/ssg` config\n    |&gt; glimra.add_static_stylesheet(syntax_highlighter: syntax_highlighter)\n    |&gt; ssg.build\n}\n```\n\nYou can also link to the generated static stylesheet in your header:\n\n```gleam\nimport glimra\n\nfn head(title: String, description: String) {\n  html.head([], [\n    html.title([], title),\n    html.meta([attribute.attribute(&quot;charset&quot;, &quot;utf-8&quot;)]),\n    html.meta([\n      attribute.attribute(&quot;name&quot;, &quot;viewport&quot;),\n      attribute.attribute(&quot;content&quot;, &quot;width=device-width, initial-scale=1&quot;),\n    ]),\n    html.link([attribute.href(&quot;/style.css&quot;), attribute.rel(&quot;stylesheet&quot;)]),\n    // `link_static_stylesheet` will use the same path as `add_static_stylesheet`\n    glimra.link_static_stylesheet(),\n  ])\n}\n```\n\nFinally, you can use the included `codeblock_renderer` with your `lustre/ssg/djot` render configuration:\n\n```gleam\npub fn parse(\n  from filepath: String,\n  // pass in the same `syntax_highlighter` you used to generate the stylesheet\n  syntax_highlighter syntax_highlighter: Config(HasTheme),\n) -&gt; String {\n  let renderer =\n    djot.Renderer(\n      ..djot.default_renderer(),\n      // this will use `codeblock_renderer` to highlight code snippets\n      codeblock: glimra.codeblock_renderer(syntax_highlighter),\n    )\n\n  let content = {\n    use file &lt;- result.try(\n      simplifile.read(filepath) |&gt; result.replace_error(Nil),\n    )\n    djot.render(file, renderer)\n  }\n\n  case content {\n    Ok(content) -&gt; content\n    Error(_) -&gt; {\n      let error_message = &quot;could not parse content from file: &quot; &lt;&gt; filepath\n      panic as error_message\n    }\n  }\n}\n```\n\n## Configuration\n\n`glimra` can be configured to include line numbers, to keep or trim whitespace, and to use a custom theme. The following configuration options are available:\n\n```gleam\npub type Config(HasTheme) {\n  line_numbers: Bool,\n  trim_whitespace: Bool,\n  theme: theme.Theme,\n}\n```\n\nThese are set with the builder pattern:\n\n```gleam\nlet syntax_highlighter =\n  glimra.new_syntax_highlighter()\n  |&gt; glimra.set_line_numbers(true)\n  |&gt; glimra.set_trim_whitespace(true)\n  |&gt; glimra.set_theme(theme.default_theme())\n```\n\nNote that the `theme` is required for any CSS generation to work!\n\n---\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glimra&gt;.\n\n## Development\n\n```sh\ngleam test  # run the tests\n```\n","url":"index.html"},{"doc":"glimra/theme","title":"Color","content":"pub type Color {\n  Color(r: Int, g: Int, b: Int)\n}\n Represents an RGB color.\nColor(r: Int, g: Int, b: Int)\n\n\nSynonyms:\nglimra/theme.Color\nglimra/theme Color","url":"glimra/theme.html#Color"},{"doc":"glimra/theme","title":"Style","content":"pub type Style {\n  Style(color: Color, italic: Bool)\n}\n Represents a style for syntax highlighting.\nStyle(color: Color, italic: Bool)\n\n\nSynonyms:\nglimra/theme.Style\nglimra/theme Style","url":"glimra/theme.html#Style"},{"doc":"glimra/theme","title":"Theme","content":"pub type Theme {\n  Theme(\n    background_color: Color,\n    padding_x: Float,\n    padding_y: Float,\n    border_radius: Float,\n    variable: Style,\n    variable_builtin: Style,\n    variable_member: Style,\n    variable_parameter_builtin: Style,\n    variable_parameter: Style,\n    constant: Style,\n    constant_builtin: Style,\n    constant_macro: Style,\n    module: Style,\n    label: Style,\n    string: Style,\n    string_documentation: Style,\n    string_escape: Style,\n    string_regexp: Style,\n    string_special: Style,\n    character: Style,\n    character_special: Style,\n    boolean: Style,\n    number: Style,\n    type_: Style,\n    type_builtin: Style,\n    type_definition: Style,\n    attribute: Style,\n    attribute_builtin: Style,\n    property: Style,\n    function: Style,\n    function_builtin: Style,\n    function_call: Style,\n    function_macro: Style,\n    function_method: Style,\n    function_method_call: Style,\n    constructor: Style,\n    operator: Style,\n    keyword: Style,\n    keyword_coroutine: Style,\n    keyword_function: Style,\n    keyword_operator: Style,\n    keyword_import: Style,\n    keyword_type: Style,\n    keyword_modifier: Style,\n    keyword_repeat: Style,\n    keyword_return: Style,\n    keyword_debug: Style,\n    keyword_exception: Style,\n    keyword_conditional: Style,\n    keyword_conditional_ternary: Style,\n    punctuation: Style,\n    punctuation_bracket: Style,\n    punctuation_delimiter: Style,\n    punctuation_special: Style,\n    comment: Style,\n    comment_documentation: Style,\n    tag: Style,\n    tag_builtin: Style,\n    tag_attribute: Style,\n    tag_delimiter: Style,\n  )\n}\n Represents a syntax highlighting theme. This includes styles for\n various code elements such as variables, functions, types, keywords,\n punctuation, comments, and tags.\nTheme(\n  background_color: Color,\n  padding_x: Float,\n  padding_y: Float,\n  border_radius: Float,\n  variable: Style,\n  variable_builtin: Style,\n  variable_member: Style,\n  variable_parameter_builtin: Style,\n  variable_parameter: Style,\n  constant: Style,\n  constant_builtin: Style,\n  constant_macro: Style,\n  module: Style,\n  label: Style,\n  string: Style,\n  string_documentation: Style,\n  string_escape: Style,\n  string_regexp: Style,\n  string_special: Style,\n  character: Style,\n  character_special: Style,\n  boolean: Style,\n  number: Style,\n  type_: Style,\n  type_builtin: Style,\n  type_definition: Style,\n  attribute: Style,\n  attribute_builtin: Style,\n  property: Style,\n  function: Style,\n  function_builtin: Style,\n  function_call: Style,\n  function_macro: Style,\n  function_method: Style,\n  function_method_call: Style,\n  constructor: Style,\n  operator: Style,\n  keyword: Style,\n  keyword_coroutine: Style,\n  keyword_function: Style,\n  keyword_operator: Style,\n  keyword_import: Style,\n  keyword_type: Style,\n  keyword_modifier: Style,\n  keyword_repeat: Style,\n  keyword_return: Style,\n  keyword_debug: Style,\n  keyword_exception: Style,\n  keyword_conditional: Style,\n  keyword_conditional_ternary: Style,\n  punctuation: Style,\n  punctuation_bracket: Style,\n  punctuation_delimiter: Style,\n  punctuation_special: Style,\n  comment: Style,\n  comment_documentation: Style,\n  tag: Style,\n  tag_builtin: Style,\n  tag_attribute: Style,\n  tag_delimiter: Style,\n)\n\n\nSynonyms:\nglimra/theme.Theme\nglimra/theme Theme","url":"glimra/theme.html#Theme"},{"doc":"glimra/theme","title":"default_theme","content":"pub fn default_theme() -&gt; Theme\n Returns the default theme for syntax highlighting.\n \n This theme is based on Catppuccin Mocha, a community-driven pastel theme.\n \nSynonyms:\nglimra/theme.default_theme\nglimra/theme default_theme","url":"glimra/theme.html#default_theme"},{"doc":"glimra/theme","title":"to_css","content":"pub fn to_css(theme t: Theme) -&gt; String\n Converts a `Theme` into a complete CSS stylesheet as a string.\n\n This function generates CSS classes for all the different styles included\n in the theme, ready to be applied to code elements in HTML.\n\nSynonyms:\nglimra/theme.to_css\nglimra/theme to_css","url":"glimra/theme.html#to_css"},{"doc":"glimra/theme","title":"glimra/theme","content":" A module that defines and manages themes for syntax highlighting.\n \n The module provides types and functions for creating and applying color\n styles to different elements of code, such as variables, functions, keywords,\n and more. The `Theme` type encapsulates all the styles necessary for\n syntax highlighting, and the module includes functions to convert these\n themes into CSS.","url":"glimra/theme.html"},{"doc":"glimra","title":"Config","content":"pub opaque type Config(has_theme)\n A configuration for the syntax highlighter with a theme.\n\n - `line_numbers`: Whether to display line numbers.\n - `trim_source`: Whether to trim whitespace from the source code.\n - `theme`: A theme to style the highlighted code.\n\n\nSynonyms:\nglimra.Config\nglimra Config","url":"glimra.html#Config"},{"doc":"glimra","title":"HasTheme","content":"pub type HasTheme\n A phantom type representing a configuration with a theme.\n\nSynonyms:\nglimra.HasTheme\nglimra HasTheme","url":"glimra.html#HasTheme"},{"doc":"glimra","title":"NoTheme","content":"pub type NoTheme\n A phantom type representing a configuration without a theme.\n\nSynonyms:\nglimra.NoTheme\nglimra NoTheme","url":"glimra.html#NoTheme"},{"doc":"glimra","title":"SyntaxHighlightingError","content":"pub type SyntaxHighlightingError {\n  UnsupportedLanguage(language: String)\n  TreeSitterError\n  UnmatchedHighlightEvents\n}\n Possible errors that can occur during syntax highlighting.\nUnsupportedLanguage(language: String)\n The specified language is not supported.\n\nTreeSitterError\n An error occurred with the Tree-sitter syntax highlighting library.\n\nUnmatchedHighlightEvents\n There were unmatched highlight events during the syntax highlighting process.\n\nSynonyms:\nglimra.SyntaxHighlightingError\nglimra SyntaxHighlightingError","url":"glimra.html#SyntaxHighlightingError"},{"doc":"glimra","title":"add_static_stylesheet","content":"pub fn add_static_stylesheet(\n  ssg_config ssg_config: Config(a, b, c),\n  syntax_highlighter syntax_highlighter: glimra.Config(HasTheme),\n) -&gt; Config(a, b, c)\n Add a static stylesheet for syntax highlighting to a lustre/ssg configuration.\n\n - `ssg_config`: The static site generator configuration.\n - `syntax_highlighter`: The syntax highlighter configuration with a theme.\n\nSynonyms:\nglimra.add_static_stylesheet\nglimra add_static_stylesheet","url":"glimra.html#add_static_stylesheet"},{"doc":"glimra","title":"codeblock_renderer","content":"pub fn codeblock_renderer(\n  syntax_highlighter syntax_highlighter: Config(HasTheme),\n) -&gt; fn(Dict(String, String), Option(String), String) -&gt;\n  Element(Nil)\n Create a renderer function for code blocks that uses the syntax highlighter.\n\n - `syntax_highlighter`: The syntax highlighter configuration with a theme.\n\nSynonyms:\nglimra.codeblock_renderer\nglimra codeblock_renderer","url":"glimra.html#codeblock_renderer"},{"doc":"glimra","title":"enable_line_numbers","content":"pub fn enable_line_numbers(config config: Config(a)) -&gt; Config(a)\n Enable line numbers in the syntax highlighter configuration.\n\nSynonyms:\nglimra.enable_line_numbers\nglimra enable_line_numbers","url":"glimra.html#enable_line_numbers"},{"doc":"glimra","title":"link_static_stylesheet","content":"pub fn link_static_stylesheet() -&gt; Element(a)\n Generate a link element to include the static syntax highlighting stylesheet.\n\nSynonyms:\nglimra.link_static_stylesheet\nglimra link_static_stylesheet","url":"glimra.html#link_static_stylesheet"},{"doc":"glimra","title":"new_syntax_highlighter","content":"pub fn new_syntax_highlighter() -&gt; Config(NoTheme)\n Create a new syntax highlighter configuration with default settings.\n\n The default configuration has line numbers disabled and source trimming\n enabled, with no theme applied.\n\nSynonyms:\nglimra.new_syntax_highlighter\nglimra new_syntax_highlighter","url":"glimra.html#new_syntax_highlighter"},{"doc":"glimra","title":"set_theme","content":"pub fn set_theme(\n  config config: Config(NoTheme),\n  theme theme: Theme,\n) -&gt; Config(HasTheme)\n Apply a theme to the syntax highlighter configuration.\n\nSynonyms:\nglimra.set_theme\nglimra set_theme","url":"glimra.html#set_theme"},{"doc":"glimra","title":"set_trim_source","content":"pub fn set_trim_source(\n  config config: Config(a),\n  trim_source trim_source: Bool,\n) -&gt; Config(a)\n Set whether to trim the source code in the syntax highlighter configuration.\n\n - `trim_source`: Whether to trim the source code.\n\nSynonyms:\nglimra.set_trim_source\nglimra set_trim_source","url":"glimra.html#set_trim_source"},{"doc":"glimra","title":"syntax_highlight","content":"pub fn syntax_highlight(\n  config config: Config(a),\n  source source: String,\n  language language: String,\n) -&gt; Result(Element(Nil), SyntaxHighlightingError)\n Perform syntax highlighting on the provided source code using the given\n configuration and programming language.\n\n Returns a Lustre `Element` on success, or a `SyntaxHighlightingError` on failure.\n\n - `config`: The syntax highlighter configuration.\n - `source`: The source code to highlight.\n - `language`: The programming language of the source code.\n\nSynonyms:\nglimra.syntax_highlight\nglimra syntax_highlight","url":"glimra.html#syntax_highlight"},{"doc":"glimra","title":"to_css","content":"pub fn to_css(config config: Config(HasTheme)) -&gt; String\n Generate CSS for the syntax highlighter configuration.\n\n The CSS includes styles for the highlighted code blocks based on the\n configuration&#39;s theme.\n\nSynonyms:\nglimra.to_css\nglimra to_css","url":"glimra.html#to_css"},{"doc":"glimra","title":"glimra","content":" `glimra` is a zero runtime syntax highlighter for `lustre/ssg`.\n\n In Swedish, `glimra` describes the brilliant gleam or lustre that comes from a polished,\n reflective surface, capturing the essence of light shining off something smooth and glossy.\n\n `glimra` uses [NIFs](https://www.erlang.org/doc/system/nif) to extract syntax highlighting\n events provided by the [`tree-sitter`](https://crates.io/crates/tree-sitter) and\n [`tree-sitter-highlight`](https://crates.io/crates/tree-sitter-highlight) crates.\n This allows `glimra` to provide syntax highlighting for a wide range of languages with minimal effort.","url":"glimra.html"}]);